@@ -1,12 +1,8 @@
-/* DSTART                                                                    */
-/*                                                                           */
-/*           maildrop - mail delivery agent with filtering abilities         */
-/*                                                                           */
-/*  Copyright 1998-1999, Double Precision Inc.                               */
-/*                                                                           */
-/*  This program is distributed under the terms of the GNU General Public    */
-/*  License. See COPYING for additional information.                         */
-/* DEND                                                                      */
+/*
+** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
+** distribution information.
+*/
+
 #if	HAVE_CONFIG_H
 #include	"config.h"
 #endif
@@ -19,7 +15,7 @@
 #include	<time.h>
 #include	"numlib/numlib.h"
 
-/* $Id: rfc2045mkboundary.c,v 1.4 1999/09/21 01:51:03 mrsam Exp $ */
+/* $Id: rfc2045mkboundary.c,v 1.6 2000/08/05 21:56:07 mrsam Exp $ */
 
 #if	HAS_GETHOSTNAME
 
@@ -54,7 +50,12 @@ int	rc;
 		sprintf(cntbuf, "%d", ++cnt);
 		p=malloc(strlen(pidbuf)+strlen(timebuf)+
 			strlen(cntbuf)+10);
-		if (!p)	rfc2045_enomem();
+		if (!p)
+		{
+			rfc2045_enomem();
+			return (NULL);
+		}
+
 		sprintf(p, "=_%s-%s-%s", pidbuf, timebuf, cntbuf);
 		if ((rc=rfc2045_try_boundary(s, fd, p)) == 0)
 			break;
